@@ -3,6 +3,7 @@
  *  Copyright (C) 2003 Choe Hwanjin(krisna@kldp.org)
  *  Copyright (c) 2006 Remco den Breeje <remco@sx.mine.nu>
  *  Copyright (c) 2008 Diego Ongaro <ongardie@gmail.com>
+ *  Copyright (c) 2016 Landry Breuil <landry@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Library General Public License as published
@@ -128,13 +129,14 @@ static void datetime_font_selection_cb(GtkWidget *widget, t_datetime *dt)
     previewtext = gtk_label_get_text(GTK_LABEL(dt->time_label));
   }
 
-  dialog = gtk_font_selection_dialog_new(_("Select font"));
-  gtk_font_selection_dialog_set_font_name(GTK_FONT_SELECTION_DIALOG(dialog),
+  dialog = gtk_font_chooser_dialog_new(_("Select font"),
+                                       GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+  gtk_font_chooser_set_font(GTK_FONT_CHOOSER(dialog),
                                           fontname);
 
   if (G_LIKELY (previewtext != NULL))
   {
-    gtk_font_selection_dialog_set_preview_text(GTK_FONT_SELECTION_DIALOG(dialog),
+    gtk_font_chooser_set_preview_text(GTK_FONT_CHOOSER(dialog),
                                                previewtext);
   }
 
@@ -142,7 +144,7 @@ static void datetime_font_selection_cb(GtkWidget *widget, t_datetime *dt)
   if (result == GTK_RESPONSE_OK || result == GTK_RESPONSE_ACCEPT)
   {
     font_name =
-      gtk_font_selection_dialog_get_font_name(GTK_FONT_SELECTION_DIALOG(dialog));
+      gtk_font_chooser_get_font(GTK_FONT_CHOOSER(dialog));
 
     if (font_name != NULL)
     {
@@ -317,7 +319,6 @@ datetime_dialog_response(GtkWidget *dlg, int response, t_datetime *dt)
     g_object_set_data(G_OBJECT(dt->plugin), "dialog", NULL);
 
     gtk_widget_destroy(dlg);
-    xfce_panel_plugin_unblock_menu(dt->plugin);
     datetime_write_rc_file(dt->plugin, dt);
   }
 }
@@ -347,13 +348,11 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
 
   xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
-  xfce_panel_plugin_block_menu(plugin);
-
   dlg = xfce_titled_dialog_new_with_buttons(_("Datetime"),
-      NULL, /* or: GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))), */
-      GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
-      GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-      GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+      GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))),
+      GTK_DIALOG_DESTROY_WITH_PARENT,
+      "gtk-help", GTK_RESPONSE_HELP,
+      "gtk-close", GTK_RESPONSE_OK,
       NULL);
 
   g_object_set_data(G_OBJECT(plugin), "dialog", dlg);
@@ -370,29 +369,28 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
    * layout frame
    */
   frame = xfce_gtk_frame_box_new(_("Layout"), &bin);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), frame,
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))), frame,
       FALSE, FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(frame), 6);
 
   /* vbox */
-  vbox = gtk_vbox_new(FALSE, 8);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add(GTK_CONTAINER(bin),vbox);
 
   /* hbox */
-  hbox = gtk_hbox_new(FALSE, 2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   /* Format label */
   label = gtk_label_new(_("Format:"));
-  gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_size_group_add_widget(sg, label);
 
   /* Layout combobox */
-  layout_combobox = gtk_combo_box_new_text();
+  layout_combobox = gtk_combo_box_text_new();
   gtk_box_pack_start(GTK_BOX(hbox), layout_combobox, TRUE, TRUE, 0);
   for(i=0; i < LAYOUT_COUNT; i++)
-    gtk_combo_box_append_text(GTK_COMBO_BOX(layout_combobox), _(layout_strs[i]));
+    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(layout_combobox), _(layout_strs[i]));
   gtk_combo_box_set_active(GTK_COMBO_BOX(layout_combobox), datetime->layout);
   g_signal_connect(G_OBJECT(layout_combobox), "changed",
       G_CALLBACK(datetime_layout_changed), datetime);
@@ -404,12 +402,12 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
    * Date frame
    */
   datetime->date_frame = xfce_gtk_frame_box_new(_("Date"), &bin);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), datetime->date_frame,
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))), datetime->date_frame,
       FALSE, FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(datetime->date_frame), 6);
 
   /* vbox */
-  vbox = gtk_vbox_new(FALSE, 8);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add(GTK_CONTAINER(bin),vbox);
 
   /* tooltip label */
@@ -418,16 +416,14 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->date_tooltip_label = gtk_label_new(str);
   g_free(str);
   gtk_label_set_use_markup(GTK_LABEL(datetime->date_tooltip_label), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(datetime->date_tooltip_label), 0.0f, 0.0f);
   gtk_box_pack_start(GTK_BOX(vbox), datetime->date_tooltip_label, FALSE, FALSE, 0);
 
   /* hbox */
-  datetime->date_font_hbox = gtk_hbox_new(FALSE, 2);
+  datetime->date_font_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), datetime->date_font_hbox, FALSE, FALSE, 0);
 
   /* font label */
   label = gtk_label_new(_("Font:"));
-  gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(datetime->date_font_hbox), label, FALSE, FALSE, 0);
   gtk_size_group_add_widget(sg, label);
 
@@ -439,17 +435,16 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->date_font_selector = button;
 
   /* hbox */
-  hbox = gtk_hbox_new(FALSE, 2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   /* format label */
   label = gtk_label_new(_("Format:"));
-  gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_size_group_add_widget(sg, label);
 
   /* format combobox */
-  date_combobox = gtk_combo_box_new_text();
+  date_combobox = gtk_combo_box_text_new();
   gtk_box_pack_start(GTK_BOX(hbox), date_combobox, TRUE, TRUE, 0);
   i_custom = 0;
   for(i=0; i < DT_COMBOBOX_DATE_COUNT; i++)
@@ -458,7 +453,7 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
     {
       case DT_COMBOBOX_ITEM_TYPE_STANDARD:
         str = datetime_do_utf8strftime(dt_combobox_date[i].item, exampletm);
-        gtk_combo_box_append_text(GTK_COMBO_BOX(date_combobox), str);
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(date_combobox), str);
         g_free(str);
         /* set active
          * strcmp isn't fast, but it is done only once while opening the dialog
@@ -467,11 +462,11 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
           gtk_combo_box_set_active(GTK_COMBO_BOX(date_combobox), i);
         break;
       case DT_COMBOBOX_ITEM_TYPE_CUSTOM:
-        gtk_combo_box_append_text(GTK_COMBO_BOX(date_combobox), _(dt_combobox_date[i].item));
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(date_combobox), _(dt_combobox_date[i].item));
         i_custom = i;
         break;
       case DT_COMBOBOX_ITEM_TYPE_SEPARATOR: /* placeholder item does not need to be translated */
-        gtk_combo_box_append_text(GTK_COMBO_BOX(date_combobox), dt_combobox_date[i].item);
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(date_combobox), dt_combobox_date[i].item);
         break;
       default:
         break;
@@ -488,7 +483,7 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->date_format_combobox = date_combobox;
 
   /* hbox */
-  hbox = gtk_hbox_new(FALSE, 2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   /* format entry */
@@ -505,12 +500,12 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
    * time frame
    */
   datetime->time_frame = xfce_gtk_frame_box_new(_("Time"), &bin);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->vbox), datetime->time_frame,
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dlg))), datetime->time_frame,
       FALSE, FALSE, 0);
   gtk_container_set_border_width(GTK_CONTAINER(datetime->time_frame), 6);
 
   /* vbox */
-  vbox = gtk_vbox_new(FALSE, 8);
+  vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 8);
   gtk_container_add(GTK_CONTAINER(bin),vbox);
 
   /* tooltip label */
@@ -519,16 +514,14 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->time_tooltip_label = gtk_label_new(str);
   g_free(str);
   gtk_label_set_use_markup(GTK_LABEL(datetime->time_tooltip_label), TRUE);
-  gtk_misc_set_alignment(GTK_MISC(datetime->time_tooltip_label), 0.0f, 0.0f);
   gtk_box_pack_start(GTK_BOX(vbox), datetime->time_tooltip_label, FALSE, FALSE, 0);
 
   /* hbox */
-  datetime->time_font_hbox = gtk_hbox_new(FALSE, 2);
+  datetime->time_font_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), datetime->time_font_hbox, FALSE, FALSE, 0);
 
   /* font label */
   label = gtk_label_new(_("Font:"));
-  gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(datetime->time_font_hbox), label, FALSE, FALSE, 0);
   gtk_size_group_add_widget(sg, label);
 
@@ -540,17 +533,16 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->time_font_selector = button;
 
   /* hbox */
-  hbox = gtk_hbox_new(FALSE, 2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   /* format label */
   label = gtk_label_new(_("Format:"));
-  gtk_misc_set_alignment(GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_size_group_add_widget(sg, label);
 
   /* format combobox */
-  time_combobox = gtk_combo_box_new_text();
+  time_combobox = gtk_combo_box_text_new();
   gtk_box_pack_start(GTK_BOX(hbox), time_combobox, TRUE, TRUE, 0);
   i_custom = 0;
   for(i=0; i < DT_COMBOBOX_TIME_COUNT; i++)
@@ -559,7 +551,7 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
     {
       case DT_COMBOBOX_ITEM_TYPE_STANDARD:
         str = datetime_do_utf8strftime(dt_combobox_time[i].item, exampletm);
-        gtk_combo_box_append_text(GTK_COMBO_BOX(time_combobox), str);
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(time_combobox), str);
         g_free(str);
         /* set active
          * strcmp isn't fast, but it is done only once while opening the dialog
@@ -568,11 +560,11 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
           gtk_combo_box_set_active(GTK_COMBO_BOX(time_combobox), i);
         break;
       case DT_COMBOBOX_ITEM_TYPE_CUSTOM:
-        gtk_combo_box_append_text(GTK_COMBO_BOX(time_combobox), _(dt_combobox_time[i].item));
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(time_combobox), _(dt_combobox_time[i].item));
         i_custom = i;
         break;
       case DT_COMBOBOX_ITEM_TYPE_SEPARATOR: /* placeholder item does not need to be translated */
-        gtk_combo_box_append_text(GTK_COMBO_BOX(time_combobox), dt_combobox_time[i].item);
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(time_combobox), dt_combobox_time[i].item);
         break;
       default:
         break;
@@ -589,7 +581,7 @@ datetime_properties_dialog(XfcePanelPlugin *plugin, t_datetime * datetime)
   datetime->time_format_combobox = time_combobox;
 
   /* hbox */
-  hbox = gtk_hbox_new(FALSE, 2);
+  hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   /* format entry */
