@@ -349,6 +349,19 @@ static void datetime_update_date_font(t_datetime *datetime)
     GtkCssProvider *css_provider;
     gchar * css;
 #if GTK_CHECK_VERSION (3, 20, 0)
+  PangoFontDescription *font;
+  font = pango_font_description_from_string(datetime->date_font);
+  if (G_LIKELY (font))
+  {
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+                          pango_font_description_get_family (font),
+                          pango_font_description_get_size (font) / PANGO_SCALE,
+                          (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
+                           pango_font_description_get_style(font) == PANGO_STYLE_OBLIQUE) ? "italic" : "normal",
+                          (pango_font_description_get_weight(font) >= PANGO_WEIGHT_BOLD) ? "bold" : "normal");
+    pango_font_description_free (font);
+  }
+  else
     css = g_strdup_printf("label { font: %s; }",
 #else
     css = g_strdup_printf(".label { font: %s; }",
@@ -381,6 +394,19 @@ static void datetime_update_time_font(t_datetime *datetime)
     GtkCssProvider *css_provider;
     gchar * css;
 #if GTK_CHECK_VERSION (3, 20, 0)
+  PangoFontDescription *font;
+  font = pango_font_description_from_string(datetime->time_font);
+  if (G_LIKELY (font))
+  {
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+                          pango_font_description_get_family (font),
+                          pango_font_description_get_size (font) / PANGO_SCALE,
+                          (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
+                           pango_font_description_get_style(font) == PANGO_STYLE_OBLIQUE) ? "italic" : "normal",
+                          (pango_font_description_get_weight(font) >= PANGO_WEIGHT_BOLD) ? "bold" : "normal");
+    pango_font_description_free (font);
+  }
+  else
     css = g_strdup_printf("label { font: %s; }",
 #else
     css = g_strdup_printf(".label { font: %s; }",
